library(tidyverse)
library(ggplot2)
library(ggrepel)
#library(taxize)
library(reshape)

#=======================
# Read in the metadata and count data
#=======================

metadata <- read.delim("../metadata/metadata_update.tsv")

dir_dat <- "/media/henrike/E586-BCAE/Data_for_HeaDS/generated_data/bracken/"
plot_dir <- "/media/henrike/E586-BCAE/Data_for_HeaDS/figures_HZ/"

theme_set(theme_bw(base_size = 22))

#=======================
#virulence factors
#=======================

#load in number of reads mapped to each vir factor per sample (made by Blaine)
vir_counts <- read.csv(paste0(dir_dat,'../virulence_counts.csv'))
rownames(vir_counts) <- vir_counts$gene
vir_counts <- vir_counts %>% select(-gene, -La125) #drop the control sample
colnames(vir_counts) <- gsub('Lasse', 'La', colnames(vir_counts))

vir_counts_scaled <- data.frame(dummy = c(0,0,0))

for (i in colnames(vir_counts)) {
  print(i)
  print(vir_counts[,i])
  print(vir_counts[,i] * metadata[metadata$sample == i,c('scaling')])
  vir_counts_scaled <- cbind(vir_counts_scaled, vir_counts[,i] * metadata[metadata$sample == i,c('scaling')] )
}
colnames(vir_counts_scaled) <- c('dummy', colnames(vir_counts))
vir_counts_scaled <- vir_counts_scaled %>% select(-dummy)
vir_counts_scaled$gene <- rownames(vir_counts)

write.csv(vir_counts_scaled, file = paste0(dir_dat,'../virulence_counts_scaled.csv') , row.names = F)
vir_counts_scaled <- read.csv(paste0(dir_dat,'../virulence_counts_scaled.csv'))

vir_counts_scaled[,1:5]
long_vir_cts <- vir_counts_scaled %>% 
  pivot_longer(!gene, names_to = 'sample', values_to = 'scaled_vir_fct_cts')

head(long_vir_cts)

#add the bfrag and fnuc cts

cts <- read.csv(paste0(dir_dat, 'OTU_count_table_scaled_filtered.out'), sep = '\t') 
tax <- read.csv(paste0(dir_dat, 'tax_table.csv'), sep = '\t')

cts[is.na(cts)] <-0 

# merge the taxonomy info to the counts so we can select the rows for the two bacteria
cts$taxID <- rownames(cts)
m <- merge(cts, tax, by = 'taxID', all.x = T)

#select F. nuc
fnuc_cts <- m %>%
  filter(species == 'Fusobacterium nucleatum') %>%
  select(-taxID, -superkingdom, -phylum, -class, -order, -family, -genus, -species) %>%
  gather(variable, value) %>%
  dplyr::rename(sample = variable, fnuc_cts = value)

#select B. frag
bfrag_cts <- m %>%
  filter(species == 'Bacteroides fragilis') %>%
  select(-taxID, -superkingdom, -phylum, -class, -order, -family, -genus, -species) %>%
  gather(variable, value) %>%
  dplyr::rename(sample = variable, bfrag_cts = value)

m_long_vir_cts <- long_vir_cts %>% left_join(fnuc_cts, by = c("sample" = "sample"))
m_long_vir_cts <- m_long_vir_cts %>% left_join(bfrag_cts, by = c("sample" = "sample"))
head(m_long_vir_cts)

#reads mapping to virulence factors VS scaled F.nuc counts
p1 <- m_long_vir_cts %>%
  ggplot(aes(x=fnuc_cts, y = scaled_vir_fct_cts)) +
  geom_point() +
  facet_wrap(~gene) +
  xlab('Scaled counts F. nuc.') + 
  ylab('Scaled read counts virulence factor') +
  geom_text_repel(aes(label = ifelse(scaled_vir_fct_cts > 80, sample, '')), size = 6)

png(filename = paste0(plot_dir, 'vir_factor_cts_VS_fnuc.png'), width = 1000, height = 600)
p1
dev.off()

#reads mapping to virulence factors VS scaled B.frag counts
p2 <- m_long_vir_cts %>%
  ggplot(aes(x=bfrag_cts, y = scaled_vir_fct_cts)) +
  geom_point() +
  facet_wrap(~gene) +
  xlab('Scaled counts B. frag.') + 
  ylab('Scaled read counts virulence factor') +
  geom_text_repel(aes(label = ifelse(scaled_vir_fct_cts > 80, sample, '')), size = 6) +
  theme(axis.text.x = element_text(angle = 45, vjust = 1, hjust=1))

png(filename = paste0(plot_dir, 'vir_factor_cts_VS_bfrag.png'), width = 1000, height = 600)
p2
dev.off()

